<%inherit file="base.html"/>
<%def name="head()">
</%def>
<%def name="body()">
    <div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-th"></span> ${title}<a class="badge pull-right" href="javascript:history.go(-1);">返回</a></div>
    <div class="panel-body">
            % if msg:
            <div class="alert alert-info">${msg}</div>
            % endif
    </div>
</div>
</%def>