<%inherit file="base.html"/>
<%def name="head()">
<script>
    % if not permit.match('/param/update'):
    $(document).ready(function (){
        $("input").each(function() { 
            $(this).attr("readonly", 'readonly');  
        })  
        $("textarea").each(function() { 
            $(this).attr("readonly", 'readonly');  
        })   
        $("#submit").hide();
    });
    % endif
</script>
</%def>
<%def name="body()">
<div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-th"></span> 系统参数管理 </div>
        <div class="panel-body">
            <form class="form-horizontal form-well" role="form" action="/param/update" method="post">
                ${form.render_css()}
            </form>
        </div>
    </div>
</div>
</%def>