<%inherit file="base.html"/>
<%def name="head()">
<script>

prices = {
    "0":"每月单价(元)",
    "1":"每小时单价(元)",
    "2":"买断包月总价(元)",
    "3":"买断时长总价(元)",
    "4":"每MB流量单价(元)",
    "5":"买断流量总价(元)"
}
//根据资费调整界面
function updateUI(){
    var policy = $("#product_policy").val();
    $("#lab_fee_price").html(prices[policy]);
    if(policy=="0"||policy=="1"||policy=="4"){
        // $("#fee_months").val(0);
        // $("#fee_times").val(0);
        // $("#fee_flows").val(0);
        $("#fee_months").parent().parent().hide();
        $("#fee_times").parent().parent().hide();
        $("#fee_flows").parent().parent().hide();
    }else if(policy=="2"){
        // $("#fee_times").val(0);
        // $("#fee_flows").val(0);
        $("#fee_months").parent().parent().show();
        $("#fee_times").parent().parent().hide();
        $("#fee_flows").parent().parent().hide();
    }else if(policy=="3"){
        // $("#fee_months").val(0);
        // $("#fee_flows").val(0);
        $("#fee_months").parent().parent().hide();
        $("#fee_times").parent().parent().show();
        $("#fee_flows").parent().parent().hide();
    }else if(policy=="5"){
        // $("#fee_months").val(0);
        // $("#fee_flows").val(0);
        $("#fee_months").parent().parent().hide();
        $("#fee_times").parent().parent().hide();
        $("#fee_flows").parent().parent().show();
    }

}
//页面初始化
$(document).ready(function (){
    updateUI();
    $('#product_policy').change(function() {
        updateUI();
    });  
});
</script>
</%def>
<%def name="body()">
    <div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-th"></span> ${form.title}<a class="badge pull-right" href="javascript:history.go(-1);">返回</a></div>
        <div class="panel-body">
            % if msg:
            <div class="alert alert-warning">${msg}</div>
            % endif
            <form class="form-horizontal form-well" role="form" action="${form.action}" method="post">
            ${form.render_css()}
        </form>
    </div>
</div>
</%def>