
<%def name="login_box()">
% if not get_cookie('customer'):
<div class="sidebar-box">
    <div class="login">
        <p><small></small></p>
        <a class="btn btn-default btn-md" href="/join" role="button">立即注册</a> 
        <p><small>已有账号请<a href="/login">登陆</a></small> <small><a href="/password/mail">忘记密码</a></small></p>
    </div>
</div>
% endif
</%def>

<%def name="user_box()">
% if  get_cookie('customer'):
<div class="sidebar-box">
<h4 class="list-group-item"><span class="glyphicon glyphicon-cog"></span> 我的服务</h4>
<hr>
<div class="list-group">
  <a href="/" class="list-group-item">用户账号信息</a>  
  <a href="/open" class="list-group-item">用户自助开户</a>    
  <a href="/billing" class="list-group-item">计费清单查询</a>
  <a href="/ticket" class="list-group-item">上网记录查询</a>
  % if sys_param_value('rcard_order_url') :
  <a href="${sys_param_value('rcard_order_url')}" target="_blank" class="list-group-item">充值卡购买</a>   
  % endif
</div>
</div>
% endif
</%def>

<%def name="qrcode_box()">
 % if sys_param_value('weixin_qrcode') :
<div class="sidebar-box">
  <h4 class="list-group-item"><span class="glyphicon glyphicon-qrcode"></span> 微信公众号</h4>
  <hr>
  <div class="img-center"><img src="${sys_param_value('weixin_qrcode')}"></div>
</div>
% endif
</%def>

<%def name="service_box()">
<div class="sidebar-box">
<h4 class="list-group-item"><span class="glyphicon glyphicon-comment"></span> 客服信息</h4>
<hr>
<div class="list-group">
  % if sys_param_value('service_qq') :
  % for qq in sys_param_value('service_qq').split(','):
  <a href="javascript:void();" class="list-group-item">客服QQ:${qq}</a>   
  % endfor 
  % endif
  % if sys_param_value('service_phone') :
  % for phone in sys_param_value('service_phone').split(','):
  <a href="javascript:void();" class="list-group-item">客服电话:${phone}</a>   
  % endfor 
  % endif
</div>
</div>

</%def>

