<%inherit file="base.html"/>
<%def name="head()">
</%def>
<%def name="body()">
    <div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-th"></span> ${form.title}<a class="badge pull-right" href="javascript:history.go(-1);">返回</a></div>
        <div class="panel-body">
            % if msg:
            <div class="alert alert-warning">${msg}</div>
            % endif
            <form class="form-horizontal form-well" role="form" action="${form.action}" method="post" enctype="multipart/form-data">
            ${form.render_css()}
        </form>

        <div class="">
        <div class="form-well">
            <h4>导入操作必读：</h4>
<p>1. 在导入之前，请仔细了解本系统的资费规则，针对您数据来源系统进行对照，在本系统中创建相对应的资费规则。</p>
<p>2. 导入数据是一项需要谨慎对待的工作，导入前备份您当前的数据库是必要的。</p>
<p>3. 对来源数据进行分析过滤，使用文本编辑器，Excel对数据进行整理，输出本系统对应的格式文件，比如用Excel另存为csv是一个好办法。</p>
<p>4. 本系统每次针对一个资费导入，您需要针对多个资费整理数据源文件。</p>
<hr>
       <h5>数据导入格式模板</h5>
        <table class="table">
            <thead>
            <tr>
                <th>姓名</th>
                <th>证件号</th>
                <th>手机</th>
                <th>地址</th>
                <th>账号</th>
                <th>密码</th>
                <th>开通时间</th>
                <th>过期时间</th>
                <th>余额(元)</th>
                <th>时长(小时)</th>
                <th>流量(MB)</th>
            </tr>
            </thead>
            <tbody>
              <tr>
                <td>张山</td>
                <td>42344535353533344</td>
                <td>1370033242</td>
                <td>幸福小区</td>
                <td>135099</td>
                <td>123321</td>
                <td>2013-12-30</td>
                <td>2015-12-30</td>
                <td>0.00</td>
                <td>0</td>
                <td>0</td>
            </tr>
              <tr>
                <td>李四</td>
                <td>4234453535323533344</td>
                <td>1370033242</td>
                <td>幸福小区</td>
                <td>121299</td>
                <td>123321</td>
                <td>2013-12-30</td>
                <td>2015-12-30</td>
                <td>0.00</td>
                <td>0</td>
                <td>0</td>
            </tr>            
            </tbody>
        </table>
        <h5>文件内容如下：每行一条完整记录,使用英文逗号分隔</h5>
        <p>
            张山,42344535353533344,1370033242,幸福小区,135099,123321,2013-12-30,2015-12-30,0.00,0,0<br>
            李四,42344535353533344,1370033242,幸福小区,121299,123321,2013-12-30,2015-12-30,0.00,0,0<br>
        </p>
         </div>
        </div>
    </div>
</div>
</%def>