<!DOCTYPE html>
<html lang="en">
        <head>
        <meta charset="utf-8">
        <title>error</title>
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <link rel="shortcut icon" href="/static/media/image/favicon.ico"/>
        <!-- Bootstrap core CSS -->
        <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    </head>
        <body>
        <br>
            <div class="container">
                <div class="jumbotron">
                <h3>出错了! </h3>
                <p>${msg}</p>
                <p><a class="btn btn-primary btn-lg" onclick="javascript:history.go(-1);" role="button">返回</a></p>
            </div>
        </div>
    </body>
</html>